@@ -1,7 +1,7 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 10/18/09	ELL
 // Revised: 11/11/09	ELL
@@ -14,6 +14,9 @@
 // Added table prefix handling.
 // Revised: 6/19/2013	ELL
 // Added separate text alignment for sub menus.
+// Revised: 12/16/2013	ELL
+// Modified menu location buttons to only suggest entries.  Added bottom and right offsets as well as manually
+// editted positioning.
 //
 
 	include ("check_session.php");
@@ -31,41 +34,22 @@
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
 <link rel="stylesheet" href="manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
-<script language="javascript" type="text/javascript" >
-function SelectMenu(menu)
-{
-	var url = "edit_css_menu_params.php?menu=" + menu;
-	window.location.href = url;
-}
 
-function  LoadOrientationDefaults(orientation)
-{
-	if (orientation == "vertical")
-	{
-		document.getElementById("menu_width").value = -1;
-		document.getElementById("sub_level_offset_top").value = -5;
-		document.getElementById("sub_level_offset_left").value = 80;	
-	}
-	else if (orientation == "horizontal_fixed_width")
-	{
-		document.getElementById("menu_width").value = -1;
-		document.getElementById("sub_level_offset_top").value = 0;
-		document.getElementById("sub_level_offset_left").value = 20;
-	}
-	else if (orientation == "horizontal_variable_width")
-	{
-		document.getElementById("menu_width").value = 100;
-		document.getElementById("menu_width_units").value = 1;
-		document.getElementById("sub_level_offset_top").value = 0;
-		document.getElementById("sub_level_offset_left").value = 20;
-	}
+<style type="text/css">
+#css_menu_parameters_heading	{	width:370px;	}
+#help_button	{	
+	position:relative;
+	display:block;
+	top:-15px;
+	left:330px;
+	height:31px;
+	width:31px;
+	z-index:100;
 }
+</style>
+
+<script src="js/edit_css_menu_params.js" language="javascript" type="text/javascript"></script>
 
-function OpenHelpWindow()
-{
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_css_menu_params", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
-}
-</script>
 </head>
 
 <body>
@@ -73,6 +57,9 @@ function OpenHelpWindow()
 <div align="center">
 <table width="90%" border="0" cellspacing="0" cellpadding="0">
 <tr>
+<td>
+<div class="button_heading_sub_level_1" id="css_menu_parameters_heading"><div class="button_heading_text_sub_level_1">CSS Menu Parameters Quick-Setup Editor</div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
+</td>
 <td class="bold" width="40%">
 Select a menu to add items to:
 <select name="selectMenu" id="selectMenu" onChange="javascript:SelectMenu(this.value);">
@@ -92,17 +79,7 @@ Select a menu to add items to:
 ?>
 </select>
 </td>
-<td>
-<span class="title">CSS Menu Parameters Quick-Setup Editor</span>
-</td>
-<td align="left">
-          <input type="button" name="Back" value="Back to Main Menu" onClick="window.location.href='main.php?mode=menu';" />
-		</td>
-<td align="right">
-<div id="help_button_sm" onClick="OpenHelpWindow();">
-&nbsp;
-</div>
-</td></tr>
+</tr>
 </table>
 
 <?php
@@ -238,11 +215,19 @@ Select a menu to add items to:
 	if (!is_null($row["position_top"]))
 		$menu_top = $row["position_top"];
 	else
-		$menu_top = 0;
+		$menu_top = -1000000;
 	if (!is_null($row["position_left"]))
 		$menu_left = $row["position_left"];
 	else
-		$menu_left = 0;
+		$menu_left = -1000000;
+	if (!is_null($row["position_bottom"]))
+		$menu_bottom = $row["position_bottom"];
+	else
+		$menu_bottom = -1000000;
+	if (!is_null($row["position_right"]))
+		$menu_right = $row["position_right"];
+	else
+		$menu_right = -1000000;
 	if (!is_null($row["position"]))
 		$position = $row["position"];
 	else
@@ -261,60 +246,92 @@ Select a menu to add items to:
 	$proportional_width_sub = $row["proportional_sub"];
 ?>
 
-<form name="frm_menu_params" action="save_css_menu_params.php" method="post">
-<table width="90%" border="1" cellspacing="0" cellpadding="0">
+<form name="frm_menu_params" id="frm_menu_params" action="save_css_menu_params.php" method="post">
+<table width="90%" class="group_box_table">
   <tr>
     <td>
-		<table width="100%" border="0" cellspacing="1" cellpadding="1">
+		<table width="100%" class="layout_box_table" cellspacing="1" cellpadding="1">
         <tr>
         	<td class="bold" colspan="9">Menu Layout and Origin (from upper left of page) </td>
         </tr>
         <tr>
-            <td>
-            Orientation:<br>
-				<label>
-              <input type="radio" name="OrientationGroup" value="vertical" id="OrientationGroup_0" <?php if ($orientation == "vertical") echo "checked='checked'"; ?> onChange="javascript:LoadOrientationDefaults('vertical');">
-              Vertical</label>
-              <br>
-              <label>
-                <input type="radio" name="OrientationGroup" value="horizontal_fixed_width" id="OrientationGroup_1" <?php if ($orientation == "horizontal_fixed_width") echo "checked='checked'"; ?> onChange="javascript:LoadOrientationDefaults('horizontal_fixed_width');">
-                Horizontal (fixed width)</label>
-              <br>
-              <label>
-                <input type="radio" name="OrientationGroup" value="horizontal_variable_width" id="OrientationGroup_2" <?php if ($orientation == "horizontal_variable_width") echo "checked='checked'"; ?> onChange="javascript:LoadOrientationDefaults('horizontal_variable_width');">
-              Horizontal (variable width)</label>
-            </td>
-            <td width="20%">
+            <td width="25%">
             Menu Location:<br>
-				<label>
-              <input type="radio" name="PositionGroup" value="absolute" id="PositionGroup_0" <?php if ($position != "relative") echo "checked='checked'"; ?> />
-              Top or Left</label>
-				<br>
-              <label>
-                <input type="radio" name="PositionGroup" value="relative" id="PositionGroup_1" <?php if ($position == "relative") echo "checked='checked'"; ?> />
-                Bottom or Right</label><br>
-                <span class="small_message">Note: Absolute positioning used for top or left and relative positioning used for bottom or right.</span>
+              <input type="radio" name="MenuLocationGroup" value="header" id="MenuLocationGroup_0" onChange="PreloadLocationDefaults('header');" />
+              Header<br>	
+              <input type="radio" name="MenuLocationGroup" value="top" id="MenuLocationGroup_1" onChange="PreloadLocationDefaults('top');" />
+              Top<br>
+              <input type="radio" name="MenuLocationGroup" value="left" id="MenuLocationGroup_2" onChange="PreloadLocationDefaults('left');" />
+              Left<br>
+                <input type="radio" name="MenuLocationGroup" value="right" id="MenuLocationGroup_3" onChange="PreloadLocationDefaults('right');" />
+              Right<br>
+              <input type="radio" name="MenuLocationGroup" value="bottom" id="MenuLocationGroup_4" onChange="PreloadLocationDefaults('bottom');" />
+              Bottom<br>
+                <input type="radio" name="MenuLocationGroup" value="footer" id="MenuLocationGroup_5" onChange="PreloadLocationDefaults('footer');" />
+              Footer<br>
+                <span class="small_message">Note: Selecting any of the above locations does not assign menu to one of these areas. It merely highlights this form with the typical settings for the selected area.</span>
+            </td>
+            <td valign="top">
+            Orientation:<br>
+              <span id="vertical">
+              <input type="radio" name="OrientationGroup" value="vertical" id="OrientationGroup_0" <?php if ($orientation == "vertical") echo "checked='checked'"; ?> onChange="javascript:LoadOrientationDefaults('vertical');">
+              </span>
+              Vertical
+              <br>
+              <span id="horizontal_fixed">
+              <input type="radio" name="OrientationGroup" value="horizontal_fixed_width" id="OrientationGroup_1" <?php if ($orientation == "horizontal_fixed_width") echo "checked='checked'"; ?> onChange="javascript:LoadOrientationDefaults('horizontal_fixed_width');">
+              </span>
+              Horizontal (fixed width)
+              <br>
+              <span id="horizontal_variable">
+              <input type="radio" name="OrientationGroup" value="horizontal_variable_width" id="OrientationGroup_2" <?php if ($orientation == "horizontal_variable_width") echo "checked='checked'"; ?> onChange="javascript:LoadOrientationDefaults('horizontal_variable_width');">
+              </span>
+              Horizontal (variable width)
             </td>
             <td>
-            Offset from Top:<br>
-            <input name="menu_top" type="text" id="menu_top" value="<?php echo $menu_top; ?>" size="10" />
+                <table border="0" cellpadding="0" cellspacing="0">
+                <tr>
+                <td colspan="2">Offset: </td>
+                </tr>
+                <tr>
+                <td>Top: </td>
+                <td id="offset_top"><input name="menu_top" type="text" id="menu_top" value="<?php echo $menu_top; ?>" size="10" /></td>
+                </tr>
+                <tr>
+                <td>Left: </td>
+                <td id="offset_left"><input name="menu_left" type="text" id="menu_left" value="<?php echo $menu_left; ?>" size="10" /></td>
+                </tr>
+                <tr>
+                <td>Bottom: </td>
+                <td id="offset_bottom"><input name="menu_bottom" type="text" id="menu_bottom" value="<?php echo $menu_bottom; ?>" size="10" /></td>
+                </tr>
+                <tr>
+                <td>Right: </td>
+                <td id="offset_right"><input name="menu_right" type="text" id="menu_right" value="<?php echo $menu_right; ?>" size="10" /></td>
+                </tr>
+                </table>
             </td>
-            <td>
-            Offset from Left:<br>
-            <input name="menu_left" type="text" id="menu_left" value="<?php echo $menu_left; ?>" size="10" />
-            </td>
-            <td>
+            <td valign="top">
             Menu Width:<br>
             <input name="menu_width" type="text" id="menu_width" value="<?php echo $menu_width; ?>" size="10" />
               <select name="menu_width_units" id="menu_width_units">
                 <option value="0" <?php if ($menu_width_units == 0) echo "selected='selected'"; ?>>px</option>
                 <option value="1" <?php if ($menu_width_units == 1) echo "selected='selected'"; ?>>%</option>
               </select>
+              <br/><br/>Positioning:<br/>
+              <span id="absolute">
+              <input type="radio" name="PositionGroup" value="absolute" id="PositionGroup_0" <?php if ($position != "relative") echo "checked='checked'"; ?> />
+              </span>
+              Absolute<br>
+              <span id="relative">
+               <input type="radio" name="PositionGroup" value="relative" id="PositionGroup_1" <?php if ($position == "relative") echo "checked='checked'"; ?> />
+               </span>
+              Relative<br>
               </td>
       </tr>
       </table>
       
-      <table width="100%" border="0" cellspacing="1" cellpadding="1">
+      <table width="100%" class="layout_box_table" cellspacing="1" cellpadding="1">
 	  <tr>
 	    <td class="bold">&nbsp;</td>
 	    </tr>
@@ -325,13 +342,13 @@ Select a menu to add items to:
       <tr>
       <td>
       
-      <table width="100%" border="0">
+      <table width="100%" class="layout_box_table">
 	  <tr>
 		 <td class="bold">Menu Item Size and Padding</td>
 	  </tr>
 	  <tr>
       <td>
-      <table width="100%" border="0">
+      <table width="100%" class="layout_box_table">
       <tr>
 		<td align="right">Width: </td>
 		<td>
@@ -371,7 +388,7 @@ Select a menu to add items to:
 	  </tr>
       <tr>
       <td>
-      <table width="100%" border="0">
+      <table width="100%" class="layout_box_table">
       <tr>
         <td align="center" class="bold">Padding</td>
         <td align="right">Top: </td>
@@ -396,14 +413,14 @@ Select a menu to add items to:
       </tr> 
       </table>
       
-      <table width="100%" border="0">
+      <table width="100%" class="layout_box_table">
 	  <tr><td>&nbsp;</td></tr>
 	 </table>
 	</td>
   </tr>
   <tr>
     <td>
-	  <table border="0" width="100%"  cellspacing="1" cellpadding="1">
+	  <table class="layout_box_table" width="100%"  cellspacing="1" cellpadding="1">
 		<tr>  
 		  <td colspan="6" class="bold">Sub Menu Positioning</td>
 		  </tr>
@@ -423,13 +440,13 @@ Select a menu to add items to:
   </tr>
   <tr>
     <td>
-	   <table border="0" width="100%" cellspacing="1" cellpadding="1">
+	   <table class="layout_box_table" width="100%" cellspacing="1" cellpadding="1">
 		  <tr>
 		    <td class="bold">Sub Menu Item Size and Padding</td>
 		    </tr>
 		  <tr>
           <td>
-          <table width="100%" border="0">
+          <table width="100%" class="layout_box_table">
            <tr>
 		    <td align="right">Width: </td>
 		    <td>
@@ -465,7 +482,7 @@ Select a menu to add items to:
 		    </tr>
 		  <tr>
 		    <td>
-            <table width="100%" border="0">
+            <table width="100%" class="layout_box_table">
       <tr>
         <td align="center" class="bold">Padding</td>
         <td align="right">Top: </td>
@@ -494,16 +511,13 @@ Select a menu to add items to:
   </tr>
 </table>
 
-<table width="90%" border="0" cellspacing="0" cellpadding="0">
+<table width="90%" class="layout_box_table" cellspacing="0" cellpadding="0">
   <tr><td colspan="2">&nbsp;</td></tr>
   <tr>
-		<td align="center" width="25%">
-          <input type="submit" value="Update" name="submit" />
+		<td align="center">
+          <div class='button_console_save' style="width:110px;" onClick="document.getElementById('frm_menu_params').submit();"><span class='button_console_text_w_icon'>Update</span></div>
           <input type="hidden" value="<?php echo $menu; ?>" name="menu" id="menu" />
 		</td>
-		<td align="center" width="50%">
-          <input type="button" name="Back" value="Back to Main Menu" onClick="window.location.href='main.php?mode=menu';" />
-		</td>
 	  </tr>
 </table>
 </form>
