@@ -1,15 +1,18 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created:	3/9/2013	ELL
 // Revised: 6/28/2013	ELL
 // Implemented popup message class.
+// Revised: 12/13/2013	ELL
+// Added refresh of main menu to update buttons and set to last selections.
 
 	include ("check_session.php");
 		
 	$mode = $_REQUEST['mode'];
+	$refresh_buttons = $_REQUEST['refresh_buttons'];
 	
 	$page_name = $_REQUEST['page_name'];
 	$blog_id = $_REQUEST['blog_id'];
@@ -55,11 +58,12 @@
 <link rel="stylesheet" href="manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
-<script type="text/javascript" src="../ckeditor/ckeditor.js"></script>
+<script language="javascript" type="text/javascript" src="../ckeditor/ckeditor.js"></script>
 <script type="text/javascript" src="js/jquery-1.9.1.min.js"></script>
-<script type="text/javascript" src="js/mouse_position.js"></script>
-<script type="text/javascript" src="js/popup_msg.js"></script>
-<script type="text/javascript" src="js/edit_page.js"></script>
+<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
+<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
+<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
+<script language="javascript" type="text/javascript" src="js/edit_page.js"></script>
 
 <script type="text/javascript" language="javascript">
  var page_name = "<?php echo $page_name; ?>";
@@ -71,6 +75,10 @@
  var userfiles = "<?php echo $userfiles; ?>";
  
  var saved = true;
+ 
+ var browser = BrowserDetect.browser;
+ var browser_version = BrowserDetect.version;
+// alert(browser + " " + browser_version);
 </script>
 
 </head>
@@ -121,7 +129,7 @@
 		
 		
 		// If IE6 or IE7, can't apply CSS.
-		if (!((navigator.appName == "Microsoft Internet Explorer") && ((navigator.appVersion.indexOf('MSIE 7') > 0) || (navigator.appVersion.indexOf('MSIE 6') > 0))))
+		if (!((browser == "Explorer") && (browser_version <= 7)))
 		{
 <?php 
 	echo "\nCKEDITOR.config.contentsCss = [";
@@ -139,13 +147,16 @@
 		}
 		CKEDITOR.config.stylesSet = 'eb_styles:/ckeditor/styles.js';
         var editorElem = document.getElementById("editorContainer");
-        CKEDITOR.config.width = '100%';
-		if (navigator.appName == "Microsoft Internet Explorer")
-        	CKEDITOR.config.height = document.body.clientHeight - 200;
-		else if (navigator.appName == "Opera")
+        CKEDITOR.config.width = '99%';
+
+		if ((browser == "Explorer") && (browser_version <= 7))
+        	CKEDITOR.config.height = document.body.clientHeight - 235;
+		else if (browser == "Opera")
 			CKEDITOR.config.height = window.innerHeight - 210;
+		if ((browser == "Explorer") && (browser_version == 8))
+			CKEDITOR.config.height = document.body.clientHeight - 210;
 		else
-			CKEDITOR.config.height = editorElem.clientHeight - 135;
+			CKEDITOR.config.height = editorElem.clientHeight - 140;
         CKEDITOR.config.resize_enabled = false;
 		
 		LoadPage();
@@ -153,28 +164,28 @@
     //]]>
     </script>
             
-      <br/>
-	  <table width="90%" align="center"><tr>
+      
+	  <table width="100%" align="center"><tr>
 	  <td align="left" class="small_message" width="9%">
       Page Name:<br/><span id="page_name_label"><?php echo $page_name; ?></span>
 	  </td>
-      <td align="center">
-      <input type="button" value="Preview" name="preview" onClick="Preview();" />
+      <td align="center" style="min-width:90px;">
+      <div class='button_console_preview_sm' style="min-width:90px;" onClick="Preview();"><span class='button_console_text_w_sm_icon'>Preview</span></div>
+	  </td>
+      <td align="center" style="min-width:80px;">
+      <div class='button_console_save_sm' style="min-width:80px;" onClick="Save('save_draft');"><span class='button_console_text_w_sm_icon'>Save</span></div>
+	  </td>
+      <td align="center" id="save_as_td" style="min-width:90px;">
+      <div class='button_console_save_sm' style="min-width:90px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_sm_icon'>Save As</span></div>
+	  </td>
+	  <td align="center" style="min-width:90px;">
+      <div class='button_console_save_sm' style="min-width:90px;" onClick="Save('publish');"><span class='button_console_text_w_sm_icon'>Publish</span></div>
+	  </td>
+      <td align="center" style="min-width:80px;">
+      <div class='button_console_cancel_sm' style="min-width:80px;" onClick="Revert();"><span class='button_console_text_w_sm_icon'>Revert</span></div>
 	  </td>
       <td align="center">
-      <input type="button" value="Save" name="save_draft" onClick="Save('save_draft');" />
-	  </td>
-      <td align="center" id="save_as_td">
-      <input type="button" value="Save As" name="save_as" onClick="ShowSaveAsMsg();" />
-	  </td>
-	  <td align="center">
-      <input type="button" value="Publish" name="publish" onClick="Save('publish');" />
-	  </td>
-      <td align="center">
-      <input type="button" value="Revert" name="revert" onClick="Revert();" />
-	  </td>
-      <td align="center">
-      <input type="button" value="See Site" name="live_view" 
+      <div class='button_console_preview_sm' style="min-width:90px;"
 <?php
 		echo "onClick=\"window.open('..";
 		echo $userfiles . $website_folder . "/";
@@ -184,29 +195,28 @@
 			echo $page_name;
 		echo ".php', '_blank');\"";
 ?>
-      />
+      ><span class='button_console_text_w_sm_icon' style="min-width:90px;">See Site</span></div>
 	  </td>
-      <td align="center"><input type="button" name="Clear" value="Clear" onClick="ClearContent();" /></td>
-	  <td align="center">
-	  <input type="button" name="Back" value="Back to Main Menu" onClick="MainMenu(saved);" />
-	  </td>
-	  <td width="8%">&nbsp;
+      <td align="center" style="min-width:75px;">
+      <div class='button_console_delete_sm' style="min-width:75px;" onClick="ClearContent();"><span class='button_console_text_w_sm_icon'>Clear</span></div>
+      </td>
+	  <td width="2%">&nbsp;
       
 	  </td>
-      <td align="center">
-      <input type="button" name="optimize" value="Optimize Images" onClick="OptimizeResetImages('optimize');" />
+      <td align="center" style="min-width:145px;">
+      <div class='button_console_image_sm' style="min-width:145px;" onClick="OptimizeResetImages('optimize');"><span class='button_console_text_w_sm_icon'>Optimize Images</span></div>
       </td>
-      <td align="center">
-      <input type="button" name="reset" value="Reset Images" onClick="OptimizeResetImages('reset');" />
+      <td align="center" style="min-width:125px;">
+      <div class='button_console_image_sm' style="min-width:125px;" onClick="OptimizeResetImages('reset');"><span class='button_console_text_w_sm_icon'>Reset Images</span></div>
       </td>
-      <td>
+      <td style="min-width:115px;">
 <?php if ($access_level != "restricted") { ?>
-      <input type="button" name="edit_styles" value="Edit Styles" onClick="window.open('edit_css.php?style_sheet=site','_blank');" />
+      <div class='button_console_edit_sm' style="min-width:115px;" onClick="window.open('edit_css.php?style_sheet=site','_blank');"><span class='button_console_text_w_sm_icon'>Edit Styles</span></div>
 <?php } else echo "&nbsp;"; ?>
       </td>
-      <td width="8%">&nbsp;</td>
-      <td align="center">
-      <div id="help_button_sm" onClick="OpenHelpWindow();">
+      <td width="1%">&nbsp;</td>
+      <td align="center" width="2%">
+      <div class="help_button" onClick="OpenHelpWindow();">
 	    &nbsp;
       </div>
 	  </td>
@@ -220,6 +230,12 @@
 	
 	if ((mode == "blog") || (special == 1))
 		document.getElementById("save_as_td").style.display = "none";
+		
+<?php 
+	if ($refresh_buttons)	{
+		echo "	parent.LoadPluginButtons();\n";
+	}
+?>
 </script>
 </body>
 </html>
