@@ -1,7 +1,7 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Revised: 11/13/2008	ELL
 // Added data type handling for text boxes as well as drop downs.
@@ -13,8 +13,12 @@
 // Fixed bug with images showing up on line after they are supposed to show up.
 // Revised: 2/8/2012	ELL
 // Added table prefix handling.
+// Revised: 12/13/2013	ELL
+// Added refresh of main menu to update buttons and set to last selections.
 //
 	include ("check_session.php");
+	
+	$options_saved = $_REQUEST['options_saved'];
 ?>
 <html>
 <head>
@@ -23,28 +27,28 @@
 <link rel="stylesheet" href="manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
-<script type="text/javascript">
-function dropdown(sel){
-	var opt_val=sel.options[sel.selectedIndex].value;
-	var opt_name=sel.name;
-    location.href="options.php?option_value=" + opt_val + "&option_name=" + opt_name;
-}
+<style type="text/css">
+#save_options_btn	{	width:110px;	}
+</style>
 
-function OpenHelpWindow()
-{
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#options", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
-}
-</script> 
+<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
+<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
+<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
+<script language="javascript" type="text/javascript" src="js/options.js"></script>
 </head>
 
 <body>
 <br>
-<form name="frmCreatePage" method="post" action="save_options.php">
+<form name="frmCreatePage" id="frmCreatePage" method="post" action="save_options.php">
 <div align="center">
-	<table>
+
+	<table width="80%" border="0"><tr><td>
+	<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1">Change Site Options</div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>
+    </td></tr></table>
+    
+	<table width="80%">
 	<tr bgcolor='#CCCCCC'><td class="sub_title">Option</td><td class="sub_title">Value</td><td>&nbsp;</td></tr>
 <?php
-//	include "../connect/db_connection.php";
 	
 	//First, create image style list for images in dropdown.
 //	echo "<style type=text/css>\n";
@@ -160,21 +164,38 @@ function OpenHelpWindow()
 		echo "</td><td>&nbsp;</td></tr>\n";
 ?>
 	<tr><td colspan="3">&nbsp;</td></tr>
-	<tr><td align="center">
-  		<input type="submit" name="Submit" value="Submit" />
-  	</td>
-	<td align="center">
-  		<input type="button" name="Back" value="Back to Main Menu" onClick="window.location.href='main.php?mode=admin';" />
-  	</td>
-    <td valign="top" align="right">
-      <div id="help_button" onClick="OpenHelpWindow();">
-        &nbsp;
-      </div>
+	<tr><td align="center" colspan="3">
+        <div class='button_console_save' id="save_options_btn" onClick="document.getElementById('frmCreatePage').submit();"><span class='button_console_text_w_icon'>Submit</span></div>
   	</td>
 	</tr>
   </table>
 </div>
 </form>
 
+<?php include("lib/popup_msg.html"); ?>
+
+<script language="JavaScript"  type="text/javascript">
+	HidePopupMsg();
+<?php	
+	if ($options_saved == 1)	{	
+		$_SESSION['button_group'] = "other_functions";
+		$_SESSION['button'] = "btn_users_site_options";
+?>
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 320;
+	popup_msg.popup_msg_type = 1;
+	popup_msg.popup_timeout = 3000;
+	popup_msg.status_msg = "The options have been saved.";
+	popup_msg.ShowPopupMsg();
+	
+	function RefreshMainMenu()
+	{
+		window.parent.location = "main.php";
+	}
+	
+	var timer = setTimeout(function() { RefreshMainMenu(); }, 3000);
+<?php	}	?>
+</script>
+
 </body>
 </html>
