@@ -1,7 +1,7 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 10/23/2009		ELL
 // Revised: 11/11/2009	ELL
@@ -18,6 +18,8 @@
 // Added separate text alignment for sub menus.
 // Revised: 7/21/2013	ELL
 // Fixed bug with opacity being left at 0 if menu freshly cerated.
+// Revised: 12/16/2013	ELL
+// Added ability to specify bottom and right offsets as well as manually editing positioning.
 // 
 //
 //
@@ -34,9 +36,13 @@
 	if (isset($_POST["PositionGroup"])) $position = $_POST["PositionGroup"];
 	else $position = "absolute";
 	if (is_numeric($_POST["menu_top"])) $menu_top = $_POST["menu_top"];
-	else $menu_top = 0;
+	else $menu_top = -1000000;
 	if (is_numeric($_POST["menu_left"])) $menu_left = $_POST["menu_left"];
-	else $menu_left = 0;
+	else $menu_left = -1000000;
+	if (is_numeric($_POST["menu_bottom"])) $menu_bottom = $_POST["menu_bottom"];
+	else $menu_bottom = -1000000;
+	if (is_numeric($_POST["menu_right"])) $menu_right = $_POST["menu_right"];
+	else $menu_right = -1000000;
 	if (is_numeric($_POST["menu_width"])) $menu_width = $_POST["menu_width"];
 	else $menu_width = 100;
 	if (is_numeric($_POST["menu_width_units"])) $menu_width_units = $_POST["menu_width_units"];
@@ -254,16 +260,19 @@
 	if ($row_count > 0)
 	{
 		//Update class record.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, position='" . $position . "', position_top=" . $menu_top
-		. ", position_top_units=0, position_left=" . $menu_left
-		. ", position_left_units=0, display='block', bkgd_opacity=-1 WHERE class='.menu_div" . $suffix . "'";
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, position='" . $position
+		. "', position_top=" . $menu_top . ", position_top_units=0, position_left=" . $menu_left
+		. ", position_left_units=0, position_bottom='" . $menu_bottom . "', position_bottom_units=0, position_right='" 
+		. $menu_right . "', position_right_units=0, display='block', bkgd_opacity=-1 WHERE class='.menu_div" . $suffix . "'";
 	}
 	else
 	{
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.menu_div" . $suffix . "', use_table_data=1, position='" . $position . "',"
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.menu_div" . $suffix 
+		. "', use_table_data=1, position='" . $position . "',"
 		. " position_top=" . $menu_top . ", position_top_units=0, position_left=" . $menu_left
-		. ", position_left_units=0, display='block', bkgd_opacity=-1";
+		. ", position_left_units=0, position_bottom='" . $menu_bottom . "', position_bottom_units=0, position_right='" 
+		. $menu_right . "', display='block', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
