@@ -1,15 +1,15 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 5/6/2010	ELL
 //	Revised: 2/10/2012	ELL
 //  Added table prefix handling.
 	
-	define('VERSION', "4.5.01");
-	define('VER_DATE',  "21 jul 2013 01:00:00");	// Release date of this version.
-	define('LAST_VER_DATE',  "02 jul 2013 01:00:00");	// Release date of last version.
+	define('VERSION', "5.0.03");
+	define('VER_DATE',  "16 dec 2013 01:00:00");	// Release date of this version.
+	define('LAST_VER_DATE',  "14 dec 2013 01:00:00");	// Release date of last version.
 	
 	include ("../connect/db_connection.php");
 	include ("../connect/config.php");
@@ -24,11 +24,22 @@
 	else
 	{
 		echo "<script language='JavaScript'  type='text/javascript'>\n";
+		
+		echo "function MoveWorkspace() {\n";
+		echo "document.getElementById('workspace').style.top='170px'\n";
+		echo "}\n";
+		
 		echo "document.getElementById('bwb_version').style.top='5px'\n";
 		echo "document.getElementById('bwb_version').style.left='350px'\n";
+		echo "document.getElementById('header_divider').style.height='60px'\n";
+		echo "document.getElementById('header_divider').style.backgroundColor='#FFFF00'\n";
+		echo "document.getElementById('header_divider').style.color='#000000'\n";
+		
+		echo "var vTimer = setTimeout(function() {MoveWorkspace()}, 1000);\n";
+		
 		echo "</script>\n";
 		echo "<span style='color:#F00;'>\n";
-		echo "Your database-revision-patch level does not match your program-files-revision level.  Please contact your system administrator.<br>\n";
+		echo "<br>Your database-revision-patch level does not match your program-files-revision level.  Please contact your system administrator.<br>\n";
 		echo "Program Files Revision Level: " . VERSION . "<br>\n";
 		echo "Database Patch Level: $version<br>\n";
 		echo "</span>\n";
